==> akonadi_1.2.1.orig.tar.gz: akonadi-1.2.1/server/src/nepomukmanager.h <==
/*
    Copyright (c) 2008 Tobias Koenig <tokoe@kde.org>

    This library is free software; you can redistribute it and/or modify it
    under the terms of the GNU Library General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This library is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
    License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to the
    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301, USA.
*/

#ifndef AKONADI_NEPOMUKMANAGER_H
#define AKONADI_NEPOMUKMANAGER_H

#include <QtCore/QHash>
#include <QtCore/QMutex>
#include <QtCore/QObject>

#include "abstractsearchmanager.h"

#include "search/queryserviceclient.h"

namespace Akonadi {

class NepomukManager : public QObject, public AbstractSearchManager
{
  Q_OBJECT

  public:
    NepomukManager( QObject* parent = 0 );
    ~NepomukManager();

    bool addSearch( const Collection &collection );
    bool removeSearch( qint64 collection );

  private:
    void reloadSearches();
    void stopSearches();

  private Q_SLOTS:
    void hitsAdded( const QList<Nepomuk::Search::Result>& entries );
    void hitsRemoved( const QList<QUrl> &entries );

  private:
    bool mValid;
    QMutex mMutex;

    QHash<Nepomuk::Search::QueryServiceClient*, qint64> mQueryMap;
    QHash<qint64, Nepomuk::Search::QueryServiceClient*> mQueryInvMap;
};

}

#endif

==> akonadi_1.3.1.orig.tar.gz: akonadi-1.3.1/server/src/nepomukmanager.h <==
/*
    Copyright (c) 2008 Tobias Koenig <tokoe@kde.org>

    This library is free software; you can redistribute it and/or modify it
    under the terms of the GNU Library General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This library is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
    License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to the
    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301, USA.
*/

#ifndef AKONADI_NEPOMUKMANAGER_H
#define AKONADI_NEPOMUKMANAGER_H

#include <QtCore/QHash>
#include <QtCore/QMutex>
#include <QtCore/QObject>

#include "abstractsearchmanager.h"

#include "search/queryserviceclient.h"

namespace Akonadi {

class NotificationCollector;

class NepomukManager : public QObject, public AbstractSearchManager
{
  Q_OBJECT

  public:
    NepomukManager( QObject* parent = 0 );
    ~NepomukManager();

    bool addSearch( const Collection &collection );
    bool removeSearch( qint64 collection );

  private:
    void reloadSearches();
    void stopSearches();

  private Q_SLOTS:
    void hitsAdded( const QList<Nepomuk::Search::Result>& entries );
    void hitsRemoved( const QList<QUrl> &entries );
    void addSearchInternal( qint64 id, const QString &searchStatement );

  private:
    bool mValid;
    QMutex mMutex;
    NotificationCollector* mCollector;

    QHash<Nepomuk::Search::QueryServiceClient*, qint64> mQueryMap;
    QHash<qint64, Nepomuk::Search::QueryServiceClient*> mQueryInvMap;
};

}

#endif
